"""
Command line interface for data_digest
"""


import click
import json

from ._data_digest import data_digest


@click.command()
@click.option('--mean', is_flag=True, help="Compute the mean value for each column of the dataset.")
@click.option('--stddev', is_flag=True, help="Compute the standard deviation for each column of the dataset.")
@click.option('--max', is_flag=True, help="Compute the max value for each column of the dataset.")
@click.option('--histogram', default=-1, help="Compute the histogram for each column of the dataset.")
@click.option('--output-path', default='', help='Store the output report into a json file')
@click.argument('path-to-dataset')
def main(mean: bool, stddev: bool, max: bool, histogram: int, output_path: str, path_to_dataset: str) -> None:
    """Quickly process bigger-than-memory data sets without a sweat!"""
    result = data_digest(filepath_in=path_to_dataset,
                         filepath_out=output_path,
                         compute_mean=mean,
                         compute_std=stddev,
                         compute_max=max,
                         compute_histogram=histogram)

    print(json.dumps(result, indent=4))
