#!/usr/bin/env python

"""
Parts of this file were taken from the luigi project
(https://github.com/spotify/luigi) as reference.
"""

import os
from setuptools import setup, find_packages


# set version
VERSION = '0.0.9'


def get_requirements():
    """Loads contents from requirements.txt."""
    requirements = []
    with open('requirements.txt') as f:
        data = f.read().splitlines()
    if any(data):
        data = data[1:]
        requirements = [item.split(";")[0].split(" ")[0] for item in data]
    return requirements


LONG_DESCRIPTION = ''


readme_note = """\
.. note::
   For the latest source, discussion, etc, please visit the
   `GitLab repository <https://gitlab.com/farrajota/jungle.ai-challenge-data-digest>`_\n\n
"""

with open('README.rst') as fobj:
    LONG_DESCRIPTION = readme_note + fobj.read()


setup(
    name='data_digest',
    version=VERSION,
    author='M. Farrajota',
    url='https://gitlab.com/farrajota/jungle.ai-challenge-data-digest',
    description="A data ingestion tool for bigger-than-memory data sets.",
    long_description=LONG_DESCRIPTION,
    license='MIT License',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: MacOS X',
        'Environment :: Win32 (MS Windows)',
        'Environment :: X11 Applications',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering',
        'License :: OSI Approved :: MIT License',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    platforms='any',
    packages=find_packages(exclude=['docs',
                                    'tests']),
    install_requires=get_requirements(),
    entry_points={
        'console_scripts': [
            'data-digest = data_digest._cli:main'
        ]
    }
)
